@@ -1,5 +1,6 @@
 """Functions to read and parse osef files/streams."""
 import socket
+import sys
 import time
 import traceback
 from collections import namedtuple, deque
@@ -11,6 +12,8 @@ import logging
 
 from osef import types
 
+TCP_TIMEOUT = 3
+
 
 # -- Public functions --
 class OsefStream:
@@ -47,7 +50,13 @@ class OsefStream:
         :return: Read binary value
         """
         if self.is_tcp:
-            return self._io_stream.recv(size)
+            try:
+                msg = self._io_stream.recv(size)
+            except socket.timeout:
+                logging.warning("Receive timeout. Closing socket.")
+                self._io_stream.close()
+                msg = None
+            return msg
 
         return self._io_stream.read(size)
 
@@ -61,6 +70,7 @@ class OsefStream:
                 tcp_socket.connect(
                     (self._parsed_path.hostname, self._parsed_path.port or 11120)
                 )
+                tcp_socket.settimeout(TCP_TIMEOUT)
                 break
             except ConnectionRefusedError:
                 time.sleep(0.005)
@@ -142,11 +152,13 @@ def build_tree(tlv: _Tlv) -> _TreeNode:
     return _TreeNode(tlv.type, None, tlv.value)
 
 
-def unpack_value(value: bytes, leaf_info: types.LeafInfo) -> Any:
+def unpack_value(value: bytes, leaf_info: types.LeafInfo, type_name: str = "") -> Any:
     """Unpack a leaf value to a python object (type depends on type of leaf).
 
     :param value: binary value to be unpacked.
     :param leaf_info: type info for unpacking and conversion to python object.
+    :param type_name: (optional) provide type name
+     to provide better feedback if an exception occurs
     :return: python object
     """
     try:
@@ -156,8 +168,8 @@ def unpack_value(value: bytes, leaf_info: types.LeafInfo) -> Any:
         # unknown parser
         return value
 
-    except error:
-        return value
+    except Exception as err:
+        raise type(err)(f'occurred while unpacking "{type_name}".') from err
 
 
 def parse_to_dict(frame_tree: _TreeNode) -> dict:
@@ -215,11 +227,10 @@ def _read_from_file(osef_stream: OsefStream, byte_number: int) -> bytes:
     blob = b""
     while len(blob) < byte_number:
         blob_inc = osef_stream.read(byte_number - len(blob))
-        blob += blob_inc
-
         # End of file
         if blob_inc is None or len(blob_inc) == 0:
             raise EOFError
+        blob += blob_inc
     return blob
 
 
@@ -264,7 +275,9 @@ def _parse_raw_to_tuple(raw_tree: _TreeNode) -> Tuple[str, Any]:
 
     # For leaves or unknown, return value
     if isinstance(type_info.node_info, types.LeafInfo):
-        return type_info.name, unpack_value(leaf_value, type_info.node_info)
+        return type_info.name, unpack_value(
+            leaf_value, type_info.node_info, type_info.name
+        )
 
     # For non-leaves, add each child to a dictionary
     tree = {}
