@@ -56,7 +56,7 @@ class OsefTypes(Enum):
     GRAVITY = 43
     EGO_MOTION = 44
     PREDICTED_POSITION = 45
-    GEOGRAPHIC_COORDINATES = 46
+    GEOGRAPHIC_POSE = 46
     OBJECT_ID_32_BITS = 47
     ZONE_BINDINGS_32_BITS = 48
     BACKGROUND_BITS = 49
@@ -64,6 +64,8 @@ class OsefTypes(Enum):
     AZIMUTHS = 51
     ELEVATIONS = 52
     DISTANCES = 53
+    LIDAR_MODEL = 54
+    SLAM_POSE_ARRAY = 55
 
 
 class PerceptIds(Enum):
@@ -82,7 +84,7 @@ class PerceptIds(Enum):
     WALL = 10
 
 
-class TrackedObjectIds(Enum):
+class TrackedObjectClassIds(Enum):
     """Ids of the objects classified by the tracking algorithm"""
 
     UNKNOWN = 0
@@ -94,6 +96,30 @@ class TrackedObjectIds(Enum):
     CAR = 6
     VAN = 7
     TWO_WHEELER = 8
+    MASK = 9
+    NO_MASK = 10
+
+
+class LidarModelIds(Enum):
+    """LiDAR models enum"""
+
+    UNKNOWN = 0
+    VELODYNE_VLP16 = 1
+    VELODYNE_VLP32 = 2
+    VELODYNE_VLS128 = 3
+    VELODYNE_HDL32 = 4
+    ROBOSENSE_BPEARL_V1 = 5
+    ROBOSENSE_BPEARL_V2 = 6
+    ROBOSENSE_RS32 = 7
+    ROBOSENSE_HELIOS = 8
+    LIVOX_HORIZON = 9
+    LIVOX_AVIA = 10
+    LIVOX_MID70 = 11
+    OUSTER = 12
+    OUTSIGHT_SA01 = 13
+    HESAI_PANDAR_XT = 14
+    HESAI_PANDAR_QT = 15
+    RANDOM = 16
 
 
 LeafInfo = namedtuple("Leaf", "parsing_function")
@@ -155,15 +181,15 @@ def _processing_bitfield_parser(value: bytes) -> dict:
     return {"background_deleted": (bitfield & (1 << background_deleted) != 0)}
 
 
-def _bool_bitfield_parser(value: bytes):
+def _bool_bitfield_parser(value: bytes) -> np.ndarray:
     if len(value) == 0:
-        return None
+        return np.array([])
     np_8bit = np.frombuffer(value, dtype=np.uint8)
     return np.unpackbits(np_8bit).astype(bool)
 
 
 def _percept_class_parser(value: bytes) -> np.ndarray:
-    dtype = [("class_code", np.int), ("class_name", "<U12")]
+    dtype = [("class_code", int), ("class_name", "<U12")]
     if len(value) == 0:
         return np.array(np.array([], dtype=dtype))
 
@@ -174,15 +200,30 @@ def _percept_class_parser(value: bytes) -> np.ndarray:
 
 
 def _class_array_parser(value: bytes) -> np.ndarray:
-    dtype = [("class_code", np.int), ("class_name", "<U12")]
+    dtype = [("class_code", int), ("class_name", "<U12")]
     if len(value) == 0:
         return np.array([], dtype=dtype)
 
     classes_iter = Struct("<L").iter_unpack(value)
-    data_list = [(code[0], TrackedObjectIds(code[0]).name) for code in classes_iter]
+    data_list = [
+        (code[0], TrackedObjectClassIds(code[0]).name) for code in classes_iter
+    ]
     return np.array(data_list, dtype=dtype)
 
 
+LidarModel = namedtuple("LidarModel", ("id", "name"))
+
+
+def _lidar_model_parser(value: bytes) -> LidarModel:
+
+    if len(value) == 0:
+        return LidarModel(0, LidarModelIds.UNKNOWN.name)
+
+    model_code = Struct("<B").unpack(value)[0]
+    data_list = LidarModel(model_code, LidarModelIds(model_code).name)
+    return data_list
+
+
 def _parse_timestamp(value: bytes) -> float:
     seconds, micro_seconds = Struct("<LL").unpack(value)
     return seconds + micro_seconds * 10 ** -6
@@ -222,12 +263,18 @@ def _pose_array_parser(value: bytes) -> List:
 
 
 def _object_properties_parser(value: bytes) -> np.ndarray:
-    dtype = [("oriented", np.bool), ("extrapolated", np.bool)]
+    dtype = [
+        ("oriented", bool),
+        ("extrapolated", bool),
+        ("has_valid_slam_pose", bool),
+    ]
     if len(value) == 0:
         return np.array([], dtype=dtype)
 
     object_iter = Struct("<B").iter_unpack(value)
-    property_list = [(bool(c[0] & 0x1), bool(c[0] & 0x2)) for c in object_iter]
+    property_list = [
+        (bool(c[0] & 0x1), bool(c[0] & 0x2), bool(c[0] & 0x4)) for c in object_iter
+    ]
     return np.array(property_list, dtype=dtype)
 
 
@@ -457,11 +504,19 @@ outsight_types = {
             )
         ),
     ),
-    OsefTypes.GEOGRAPHIC_COORDINATES.value: TypeInfo(
-        "geographic_coordinates",
+    OsefTypes.GEOGRAPHIC_POSE.value: TypeInfo(
+        "geographic_pose",
         LeafInfo(
             _get_structured_array_parser(
-                np.dtype(([("lat", np.float32), ("long", np.float32)]))
+                np.dtype(
+                    (
+                        [
+                            ("lat", np.float32),
+                            ("long", np.float32),
+                            ("heading", np.float32),
+                        ]
+                    )
+                )
             )
         ),
     ),
@@ -493,6 +548,10 @@ outsight_types = {
     OsefTypes.DISTANCES.value: TypeInfo(
         "distances", LeafInfo(_get_array_parser(np.dtype(np.float32)))
     ),
+    OsefTypes.LIDAR_MODEL.value: TypeInfo("lidar_model", LeafInfo(_lidar_model_parser)),
+    OsefTypes.SLAM_POSE_ARRAY.value: TypeInfo(
+        "slam_pose_array", LeafInfo(_pose_array_parser)
+    ),
 }
 
 
